"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def abort_multipart_upload(accountId=None, vaultName=None, uploadId=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param uploadId: [REQUIRED]
            The upload ID of the multipart upload to delete.
            
    :type uploadId: string
    """
    pass

def abort_vault_lock(accountId=None, vaultName=None):
    """
    :param accountId: The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    """
    pass

def add_tags_to_vault(accountId=None, vaultName=None, Tags=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param Tags: The tags to add to the vault. Each tag is composed of a key and a value. The value can be an empty string.
            (string) --
            (string) --
            
    :type Tags: dict
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def complete_multipart_upload(accountId=None, vaultName=None, uploadId=None, archiveSize=None, checksum=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param uploadId: [REQUIRED]
            The upload ID of the multipart upload.
            
    :type uploadId: string
    :param archiveSize: The total size, in bytes, of the entire archive. This value should be the sum of all the sizes of the individual parts that you uploaded.
    :type archiveSize: string
    :param checksum: The SHA256 tree hash of the entire archive. It is the tree hash of SHA256 tree hash of the individual parts. If the value you specify in the request does not match the SHA256 tree hash of the final assembled archive as computed by Amazon Glacier, Amazon Glacier returns an error and the request fails.
            This is a required field.Ideally you will want to compute this value with checksums from
            previous uploaded parts, using the algorithm described in
            Glacier documentation.
            But if you prefer, you can also use botocore.util.calculate_tree_hash()
            to compute it from raw file by:
            checksum = calculate_tree_hash(open('your_file.txt', 'rb'))
            
    :type checksum: string
    """
    pass

def complete_vault_lock(accountId=None, vaultName=None, lockId=None):
    """
    :param accountId: The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param lockId: [REQUIRED]
            The lockId value is the lock ID obtained from a InitiateVaultLock request.
            
    :type lockId: string
    """
    pass

def create_vault(accountId=None, vaultName=None):
    """
    :param accountId: The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    """
    pass

def delete_archive(accountId=None, vaultName=None, archiveId=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param archiveId: [REQUIRED]
            The ID of the archive to delete.
            
    :type archiveId: string
    """
    pass

def delete_vault(accountId=None, vaultName=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    """
    pass

def delete_vault_access_policy(accountId=None, vaultName=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    """
    pass

def delete_vault_notifications(accountId=None, vaultName=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    """
    pass

def describe_job(accountId=None, vaultName=None, jobId=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param jobId: [REQUIRED]
            The ID of the job to describe.
            
    :type jobId: string
    """
    pass

def describe_vault(accountId=None, vaultName=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_data_retrieval_policy(accountId=None):
    """
    :param accountId: The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            Return typedict
            ReturnsResponse Syntax{
              'Policy': {
                'Rules': [
                  {
                    'Strategy': 'string',
                    'BytesPerHour': 123
                  },
                ]
              }
            }
            Response Structure
            (dict) --Contains the Amazon Glacier response to the GetDataRetrievalPolicy request.
            Policy (dict) --Contains the returned data retrieval policy in JSON format.
            Rules (list) --The policy rule. Although this is a list type, currently there must be only one rule, which contains a Strategy field and optionally a BytesPerHour field.
            (dict) --Data retrieval policy rule.
            Strategy (string) --The type of data retrieval policy to set.
            Valid values: BytesPerHour|FreeTier|None
            BytesPerHour (integer) --The maximum number of bytes that can be retrieved in an hour.
            This field is required only if the value of the Strategy field is BytesPerHour . Your PUT operation will be rejected if the Strategy field is not set to BytesPerHour and you set this field.
            
            
            
            
    :type accountId: string
    """
    pass

def get_job_output(accountId=None, vaultName=None, jobId=None, range=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param jobId: [REQUIRED]
            The job ID whose data is downloaded.
            
    :type jobId: string
    :param range: The range of bytes to retrieve from the output. For example, if you want to download the first 1,048,576 bytes, specify 'Range: bytes=0-1048575'. By default, this operation downloads the entire output.
    :type range: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_vault_access_policy(accountId=None, vaultName=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    """
    pass

def get_vault_lock(accountId=None, vaultName=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    """
    pass

def get_vault_notifications(accountId=None, vaultName=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    """
    pass

def get_waiter():
    """
    """
    pass

def initiate_job(accountId=None, vaultName=None, jobParameters=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param jobParameters: Provides options for specifying job information.
            Format (string) --When initiating a job to retrieve a vault inventory, you can optionally add this parameter to your request to specify the output format. If you are initiating an inventory job and do not specify a Format field, JSON is the default format. Valid values are 'CSV' and 'JSON'.
            Type (string) --The job type. You can initiate a job to retrieve an archive or get an inventory of a vault. Valid values are 'archive-retrieval' and 'inventory-retrieval'.
            ArchiveId (string) --The ID of the archive that you want to retrieve. This field is required only if Type is set to archive-retrieval. An error occurs if you specify this request parameter for an inventory retrieval job request.
            Description (string) --The optional description for the job. The description must be less than or equal to 1,024 bytes. The allowable characters are 7-bit ASCII without control codes-specifically, ASCII values 32-126 decimal or 0x20-0x7E hexadecimal.
            SNSTopic (string) --The Amazon SNS topic ARN to which Amazon Glacier sends a notification when the job is completed and the output is ready for you to download. The specified topic publishes the notification to its subscribers. The SNS topic must exist.
            RetrievalByteRange (string) --The byte range to retrieve for an archive retrieval. in the form 'StartByteValue -EndByteValue ' If not specified, the whole archive is retrieved. If specified, the byte range must be megabyte (1024*1024) aligned which means that StartByteValue must be divisible by 1 MB and EndByteValue plus 1 must be divisible by 1 MB or be the end of the archive specified as the archive byte size value minus 1. If RetrievalByteRange is not megabyte aligned, this operation returns a 400 response.
            An error occurs if you specify this field for an inventory retrieval job request.
            InventoryRetrievalParameters (dict) --Input parameters used for range inventory retrieval.
            StartDate (string) --The start of the date range in UTC for vault inventory retrieval that includes archives created on or after this date. A string representation of ISO 8601 date format, for example, 2013-03-20T17:03:43Z.
            EndDate (string) --The end of the date range in UTC for vault inventory retrieval that includes archives created before this date. A string representation of ISO 8601 date format, for example, 2013-03-20T17:03:43Z.
            Limit (string) --Specifies the maximum number of inventory items returned per vault inventory retrieval request. Valid values are greater than or equal to 1.
            Marker (string) --An opaque string that represents where to continue pagination of the vault inventory retrieval results. You use the marker in a new InitiateJob request to obtain additional inventory items. If there are no more inventory items, this value is null .
            
            
    :type jobParameters: dict
    """
    pass

def initiate_multipart_upload(accountId=None, vaultName=None, archiveDescription=None, partSize=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param archiveDescription: The archive description that you are uploading in parts.
            The part size must be a megabyte (1024 KB) multiplied by a power of 2, for example 1048576 (1 MB), 2097152 (2 MB), 4194304 (4 MB), 8388608 (8 MB), and so on. The minimum allowable part size is 1 MB, and the maximum is 4 GB (4096 MB).
            
    :type archiveDescription: string
    :param partSize: The size of each part except the last, in bytes. The last part can be smaller than this part size.
    :type partSize: string
    """
    pass

def initiate_vault_lock(accountId=None, vaultName=None, policy=None):
    """
    :param accountId: The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param policy: The vault lock policy as a JSON string, which uses '' as an escape character.
            Policy (string) --The vault lock policy.
            
    :type policy: dict
    """
    pass

def list_jobs(accountId=None, vaultName=None, limit=None, marker=None, statuscode=None, completed=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param limit: Specifies that the response be limited to the specified number of items or fewer. If not specified, the List Jobs operation returns up to 1,000 jobs.
    :type limit: string
    :param marker: An opaque string used for pagination. This value specifies the job at which the listing of jobs should begin. Get the marker value from a previous List Jobs response. You need only include the marker if you are continuing the pagination of results started in a previous List Jobs request.
    :type marker: string
    :param statuscode: Specifies the type of job status to return. You can specify the following values: 'InProgress', 'Succeeded', or 'Failed'.
    :type statuscode: string
    :param completed: Specifies the state of the jobs to return. You can specify true or false .
    :type completed: string
    """
    pass

def list_multipart_uploads(accountId=None, vaultName=None, marker=None, limit=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param marker: An opaque string used for pagination. This value specifies the upload at which the listing of uploads should begin. Get the marker value from a previous List Uploads response. You need only include the marker if you are continuing the pagination of results started in a previous List Uploads request.
    :type marker: string
    :param limit: Specifies the maximum number of uploads returned in the response body. If this value is not specified, the List Uploads operation returns up to 1,000 uploads.
    :type limit: string
    """
    pass

def list_parts(accountId=None, vaultName=None, uploadId=None, marker=None, limit=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param uploadId: [REQUIRED]
            The upload ID of the multipart upload.
            
    :type uploadId: string
    :param marker: An opaque string used for pagination. This value specifies the part at which the listing of parts should begin. Get the marker value from the response of a previous List Parts response. You need only include the marker if you are continuing the pagination of results started in a previous List Parts request.
    :type marker: string
    :param limit: Specifies the maximum number of parts returned in the response body. If this value is not specified, the List Parts operation returns up to 1,000 uploads.
    :type limit: string
    """
    pass

def list_tags_for_vault(accountId=None, vaultName=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    """
    pass

def list_vaults(accountId=None, marker=None, limit=None):
    """
    :param accountId: The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param marker: A string used for pagination. The marker specifies the vault ARN after which the listing of vaults should begin.
    :type marker: string
    :param limit: The maximum number of items returned in the response. If you don't specify a value, the List Vaults operation returns up to 1,000 items.
    :type limit: string
    """
    pass

def remove_tags_from_vault(accountId=None, vaultName=None, TagKeys=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param TagKeys: A list of tag keys. Each corresponding tag is removed from the vault.
            (string) --
            
    :type TagKeys: list
    """
    pass

def set_data_retrieval_policy(accountId=None, Policy=None):
    """
    :param accountId: The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param Policy: The data retrieval policy in JSON format.
            Rules (list) --The policy rule. Although this is a list type, currently there must be only one rule, which contains a Strategy field and optionally a BytesPerHour field.
            (dict) --Data retrieval policy rule.
            Strategy (string) --The type of data retrieval policy to set.
            Valid values: BytesPerHour|FreeTier|None
            BytesPerHour (integer) --The maximum number of bytes that can be retrieved in an hour.
            This field is required only if the value of the Strategy field is BytesPerHour . Your PUT operation will be rejected if the Strategy field is not set to BytesPerHour and you set this field.
            
            
    :type Policy: dict
    """
    pass

def set_vault_access_policy(accountId=None, vaultName=None, policy=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param policy: The vault access policy as a JSON string.
            Policy (string) --The vault access policy.
            
    :type policy: dict
    """
    pass

def set_vault_notifications(accountId=None, vaultName=None, vaultNotificationConfig=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param vaultNotificationConfig: Provides options for specifying notification configuration.
            SNSTopic (string) --The Amazon Simple Notification Service (Amazon SNS) topic Amazon Resource Name (ARN).
            Events (list) --A list of one or more events for which Amazon Glacier will send a notification to the specified Amazon SNS topic.
            (string) --
            
    :type vaultNotificationConfig: dict
    """
    pass

def upload_archive(vaultName=None, accountId=None, archiveDescription=None, checksum=None, body=None):
    """
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param archiveDescription: The optional description of the archive you are uploading.
    :type archiveDescription: string
    :param checksum: The SHA256 tree hash of the data being uploaded.
            Please note that this parameter is automatically populated if it is not provided. Including this parameter is not required
            
    :type checksum: string
    :param body: The data to upload.
    :type body: bytes or seekable file-like object
    """
    pass

def upload_multipart_part(accountId=None, vaultName=None, uploadId=None, checksum=None, range=None, body=None):
    """
    :param accountId: The AccountId value is the AWS account ID of the account that owns the vault. You can either specify an AWS account ID or optionally a single apos``-`` apos (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you use an account ID, do not include any hyphens (apos-apos) in the ID.
            Note: this parameter is set to '-' bydefault if no value is not specified.
            
    :type accountId: string
    :param vaultName: [REQUIRED]
            The name of the vault.
            
    :type vaultName: string
    :param uploadId: [REQUIRED]
            The upload ID of the multipart upload.
            
    :type uploadId: string
    :param checksum: The SHA256 tree hash of the data being uploaded.
            Please note that this parameter is automatically populated if it is not provided. Including this parameter is not required
            
    :type checksum: string
    :param range: Identifies the range of bytes in the assembled archive that will be uploaded in this part. Amazon Glacier uses this information to assemble the archive in the proper sequence. The format of this header follows RFC 2616. An example header is Content-Range:bytes 0-4194303/*.
    :type range: string
    :param body: The data to upload.
    :type body: bytes or seekable file-like object
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def build_suggesters(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            Return typedict
            ReturnsResponse Syntax{
              'FieldNames': [
                'string',
              ]
            }
            Response Structure
            (dict) --The result of a BuildSuggester request. Contains a list of the fields used for suggestions.
            FieldNames (list) --A list of field names.
            (string) --A string that represents the name of an index field. CloudSearch supports regular index fields as well as dynamic fields. A dynamic field's name defines a pattern that begins or ends with a wildcard. Any document fields that don't map to a regular index field but do match a dynamic field's pattern are configured with the dynamic field's indexing options.
            Regular field names begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore). Dynamic field names must begin or end with a wildcard (*). The wildcard can also be the only character in a dynamic field name. Multiple wildcards, and wildcards embedded within a string are not supported.
            The name score is reserved and cannot be used as a field name. To reference a document's ID, you can use the name _id .
            
            
            
    :type DomainName: string
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_domain(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            A name for the domain you are creating. Allowed characters are a-z (lower-case letters), 0-9, and hyphen (-). Domain names must start with a letter or number and be at least 3 and no more than 28 characters long.
            Return typedict
            ReturnsResponse Syntax{
              'DomainStatus': {
                'DomainId': 'string',
                'DomainName': 'string',
                'ARN': 'string',
                'Created': True|False,
                'Deleted': True|False,
                'DocService': {
                  'Endpoint': 'string'
                },
                'SearchService': {
                  'Endpoint': 'string'
                },
                'RequiresIndexDocuments': True|False,
                'Processing': True|False,
                'SearchInstanceType': 'string',
                'SearchPartitionCount': 123,
                'SearchInstanceCount': 123,
                'Limits': {
                  'MaximumReplicationCount': 123,
                  'MaximumPartitionCount': 123
                }
              }
            }
            Response Structure
            (dict) --The result of a CreateDomainRequest . Contains the status of a newly created domain.
            DomainStatus (dict) --The current status of the search domain.
            DomainId (string) --An internally generated unique identifier for a domain.
            DomainName (string) --A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            ARN (string) --The Amazon Resource Name (ARN) of the search domain. See Identifiers for IAM Entities in Using AWS Identity and Access Management for more information.
            Created (boolean) --True if the search domain is created. It can take several minutes to initialize a domain when CreateDomain is called. Newly created search domains are returned from DescribeDomains with a false value for Created until domain creation is complete.
            Deleted (boolean) --True if the search domain has been deleted. The system must clean up resources dedicated to the search domain when DeleteDomain is called. Newly deleted search domains are returned from DescribeDomains with a true value for IsDeleted for several minutes until resource cleanup is complete.
            DocService (dict) --The service endpoint for updating documents in a search domain.
            Endpoint (string) --The endpoint to which service requests can be submitted. For example, search-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com or doc-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com .
            SearchService (dict) --The service endpoint for requesting search results from a search domain.
            Endpoint (string) --The endpoint to which service requests can be submitted. For example, search-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com or doc-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com .
            RequiresIndexDocuments (boolean) --True if IndexDocuments needs to be called to activate the current domain configuration.
            Processing (boolean) --True if processing is being done to activate the current domain configuration.
            SearchInstanceType (string) --The instance type that is being used to process search requests.
            SearchPartitionCount (integer) --The number of partitions across which the search index is spread.
            SearchInstanceCount (integer) --The number of search instances that are available to process search requests.
            Limits (dict) --
            MaximumReplicationCount (integer) --
            MaximumPartitionCount (integer) --
            
            
            
    :type DomainName: string
    """
    pass

def define_analysis_scheme(DomainName=None, AnalysisScheme=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param AnalysisScheme: [REQUIRED]
            Configuration information for an analysis scheme. Each analysis scheme has a unique name and specifies the language of the text to be processed. The following options can be configured for an analysis scheme: Synonyms , Stopwords , StemmingDictionary , JapaneseTokenizationDictionary and AlgorithmicStemming .
            AnalysisSchemeName (string) -- [REQUIRED]Names must begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore).
            AnalysisSchemeLanguage (string) -- [REQUIRED]An IETF RFC 4646 language code or mul for multiple languages.
            AnalysisOptions (dict) --Synonyms, stopwords, and stemming options for an analysis scheme. Includes tokenization dictionary for Japanese.
            Synonyms (string) --A JSON object that defines synonym groups and aliases. A synonym group is an array of arrays, where each sub-array is a group of terms where each term in the group is considered a synonym of every other term in the group. The aliases value is an object that contains a collection of string:value pairs where the string specifies a term and the array of values specifies each of the aliases for that term. An alias is considered a synonym of the specified term, but the term is not considered a synonym of the alias. For more information about specifying synonyms, see Synonyms in the Amazon CloudSearch Developer Guide .
            Stopwords (string) --A JSON array of terms to ignore during indexing and searching. For example, ['a', 'an', 'the', 'of'] . The stopwords dictionary must explicitly list each word you want to ignore. Wildcards and regular expressions are not supported.
            StemmingDictionary (string) --A JSON object that contains a collection of string:value pairs that each map a term to its stem. For example, {'term1': 'stem1', 'term2': 'stem2', 'term3': 'stem3'} . The stemming dictionary is applied in addition to any algorithmic stemming. This enables you to override the results of the algorithmic stemming to correct specific cases of overstemming or understemming. The maximum size of a stemming dictionary is 500 KB.
            JapaneseTokenizationDictionary (string) --A JSON array that contains a collection of terms, tokens, readings and part of speech for Japanese Tokenizaiton. The Japanese tokenization dictionary enables you to override the default tokenization for selected terms. This is only valid for Japanese language fields.
            AlgorithmicStemming (string) --The level of algorithmic stemming to perform: none , minimal , light , or full . The available levels vary depending on the language. For more information, see Language Specific Text Processing Settings in the Amazon CloudSearch Developer Guide
            
            
    :type AnalysisScheme: dict
    """
    pass

def define_expression(DomainName=None, Expression=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param Expression: [REQUIRED]
            A named expression that can be evaluated at search time. Can be used to sort the search results, define other expressions, or return computed information in the search results.
            ExpressionName (string) -- [REQUIRED]Names must begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore).
            ExpressionValue (string) -- [REQUIRED]The expression to evaluate for sorting while processing a search request. The Expression syntax is based on JavaScript expressions. For more information, see Configuring Expressions in the Amazon CloudSearch Developer Guide .
            
    :type Expression: dict
    """
    pass

def define_index_field(DomainName=None, IndexField=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param IndexField: [REQUIRED]
            The index field and field options you want to configure.
            IndexFieldName (string) -- [REQUIRED]A string that represents the name of an index field. CloudSearch supports regular index fields as well as dynamic fields. A dynamic field's name defines a pattern that begins or ends with a wildcard. Any document fields that don't map to a regular index field but do match a dynamic field's pattern are configured with the dynamic field's indexing options.
            Regular field names begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore). Dynamic field names must begin or end with a wildcard (*). The wildcard can also be the only character in a dynamic field name. Multiple wildcards, and wildcards embedded within a string are not supported.
            The name score is reserved and cannot be used as a field name. To reference a document's ID, you can use the name _id .
            IndexFieldType (string) -- [REQUIRED]The type of field. The valid options for a field depend on the field type. For more information about the supported field types, see Configuring Index Fields in the Amazon CloudSearch Developer Guide .
            IntOptions (dict) --Options for a 64-bit signed integer field. Present if IndexFieldType specifies the field is of type int . All options are enabled by default.
            DefaultValue (integer) -- A value to use for the field if the field isn't specified for a document. This can be important if you are using the field in an expression and that field is not present in every document.
            SourceField (string) --The name of the source field to map to the field.
            FacetEnabled (boolean) --Whether facet information can be returned for the field.
            SearchEnabled (boolean) --Whether the contents of the field are searchable.
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            SortEnabled (boolean) --Whether the field can be used to sort the search results.
            DoubleOptions (dict) --Options for a double-precision 64-bit floating point field. Present if IndexFieldType specifies the field is of type double . All options are enabled by default.
            DefaultValue (float) --A value to use for the field if the field isn't specified for a document. This can be important if you are using the field in an expression and that field is not present in every document.
            SourceField (string) --The name of the source field to map to the field.
            FacetEnabled (boolean) --Whether facet information can be returned for the field.
            SearchEnabled (boolean) --Whether the contents of the field are searchable.
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            SortEnabled (boolean) --Whether the field can be used to sort the search results.
            LiteralOptions (dict) --Options for literal field. Present if IndexFieldType specifies the field is of type literal . All options are enabled by default.
            DefaultValue (string) -- A value to use for the field if the field isn't specified for a document.
            SourceField (string) --A string that represents the name of an index field. CloudSearch supports regular index fields as well as dynamic fields. A dynamic field's name defines a pattern that begins or ends with a wildcard. Any document fields that don't map to a regular index field but do match a dynamic field's pattern are configured with the dynamic field's indexing options.
            Regular field names begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore). Dynamic field names must begin or end with a wildcard (*). The wildcard can also be the only character in a dynamic field name. Multiple wildcards, and wildcards embedded within a string are not supported.
            The name score is reserved and cannot be used as a field name. To reference a document's ID, you can use the name _id .
            FacetEnabled (boolean) --Whether facet information can be returned for the field.
            SearchEnabled (boolean) --Whether the contents of the field are searchable.
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            SortEnabled (boolean) --Whether the field can be used to sort the search results.
            TextOptions (dict) --Options for text field. Present if IndexFieldType specifies the field is of type text . A text field is always searchable. All options are enabled by default.
            DefaultValue (string) -- A value to use for the field if the field isn't specified for a document.
            SourceField (string) --A string that represents the name of an index field. CloudSearch supports regular index fields as well as dynamic fields. A dynamic field's name defines a pattern that begins or ends with a wildcard. Any document fields that don't map to a regular index field but do match a dynamic field's pattern are configured with the dynamic field's indexing options.
            Regular field names begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore). Dynamic field names must begin or end with a wildcard (*). The wildcard can also be the only character in a dynamic field name. Multiple wildcards, and wildcards embedded within a string are not supported.
            The name score is reserved and cannot be used as a field name. To reference a document's ID, you can use the name _id .
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            SortEnabled (boolean) --Whether the field can be used to sort the search results.
            HighlightEnabled (boolean) --Whether highlights can be returned for the field.
            AnalysisScheme (string) --The name of an analysis scheme for a text field.
            DateOptions (dict) --Options for a date field. Dates and times are specified in UTC (Coordinated Universal Time) according to IETF RFC3339: yyyy-mm-ddT00:00:00Z. Present if IndexFieldType specifies the field is of type date . All options are enabled by default.
            DefaultValue (string) -- A value to use for the field if the field isn't specified for a document.
            SourceField (string) --A string that represents the name of an index field. CloudSearch supports regular index fields as well as dynamic fields. A dynamic field's name defines a pattern that begins or ends with a wildcard. Any document fields that don't map to a regular index field but do match a dynamic field's pattern are configured with the dynamic field's indexing options.
            Regular field names begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore). Dynamic field names must begin or end with a wildcard (*). The wildcard can also be the only character in a dynamic field name. Multiple wildcards, and wildcards embedded within a string are not supported.
            The name score is reserved and cannot be used as a field name. To reference a document's ID, you can use the name _id .
            FacetEnabled (boolean) --Whether facet information can be returned for the field.
            SearchEnabled (boolean) --Whether the contents of the field are searchable.
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            SortEnabled (boolean) --Whether the field can be used to sort the search results.
            LatLonOptions (dict) --Options for a latlon field. A latlon field contains a location stored as a latitude and longitude value pair. Present if IndexFieldType specifies the field is of type latlon . All options are enabled by default.
            DefaultValue (string) -- A value to use for the field if the field isn't specified for a document.
            SourceField (string) --A string that represents the name of an index field. CloudSearch supports regular index fields as well as dynamic fields. A dynamic field's name defines a pattern that begins or ends with a wildcard. Any document fields that don't map to a regular index field but do match a dynamic field's pattern are configured with the dynamic field's indexing options.
            Regular field names begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore). Dynamic field names must begin or end with a wildcard (*). The wildcard can also be the only character in a dynamic field name. Multiple wildcards, and wildcards embedded within a string are not supported.
            The name score is reserved and cannot be used as a field name. To reference a document's ID, you can use the name _id .
            FacetEnabled (boolean) --Whether facet information can be returned for the field.
            SearchEnabled (boolean) --Whether the contents of the field are searchable.
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            SortEnabled (boolean) --Whether the field can be used to sort the search results.
            IntArrayOptions (dict) --Options for a field that contains an array of 64-bit signed integers. Present if IndexFieldType specifies the field is of type int-array . All options are enabled by default.
            DefaultValue (integer) -- A value to use for the field if the field isn't specified for a document.
            SourceFields (string) --A list of source fields to map to the field.
            FacetEnabled (boolean) --Whether facet information can be returned for the field.
            SearchEnabled (boolean) --Whether the contents of the field are searchable.
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            DoubleArrayOptions (dict) --Options for a field that contains an array of double-precision 64-bit floating point values. Present if IndexFieldType specifies the field is of type double-array . All options are enabled by default.
            DefaultValue (float) -- A value to use for the field if the field isn't specified for a document.
            SourceFields (string) --A list of source fields to map to the field.
            FacetEnabled (boolean) --Whether facet information can be returned for the field.
            SearchEnabled (boolean) --Whether the contents of the field are searchable.
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            LiteralArrayOptions (dict) --Options for a field that contains an array of literal strings. Present if IndexFieldType specifies the field is of type literal-array . All options are enabled by default.
            DefaultValue (string) -- A value to use for the field if the field isn't specified for a document.
            SourceFields (string) --A list of source fields to map to the field.
            FacetEnabled (boolean) --Whether facet information can be returned for the field.
            SearchEnabled (boolean) --Whether the contents of the field are searchable.
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            TextArrayOptions (dict) --Options for a field that contains an array of text strings. Present if IndexFieldType specifies the field is of type text-array . A text-array field is always searchable. All options are enabled by default.
            DefaultValue (string) -- A value to use for the field if the field isn't specified for a document.
            SourceFields (string) --A list of source fields to map to the field.
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            HighlightEnabled (boolean) --Whether highlights can be returned for the field.
            AnalysisScheme (string) --The name of an analysis scheme for a text-array field.
            DateArrayOptions (dict) --Options for a field that contains an array of dates. Present if IndexFieldType specifies the field is of type date-array . All options are enabled by default.
            DefaultValue (string) -- A value to use for the field if the field isn't specified for a document.
            SourceFields (string) --A list of source fields to map to the field.
            FacetEnabled (boolean) --Whether facet information can be returned for the field.
            SearchEnabled (boolean) --Whether the contents of the field are searchable.
            ReturnEnabled (boolean) --Whether the contents of the field can be returned in the search results.
            
            
    :type IndexField: dict
    """
    pass

def define_suggester(DomainName=None, Suggester=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param Suggester: [REQUIRED]
            Configuration information for a search suggester. Each suggester has a unique name and specifies the text field you want to use for suggestions. The following options can be configured for a suggester: FuzzyMatching , SortExpression .
            SuggesterName (string) -- [REQUIRED]Names must begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore).
            DocumentSuggesterOptions (dict) -- [REQUIRED]Options for a search suggester.
            SourceField (string) -- [REQUIRED]The name of the index field you want to use for suggestions.
            FuzzyMatching (string) --The level of fuzziness allowed when suggesting matches for a string: none , low , or high . With none, the specified string is treated as an exact prefix. With low, suggestions must differ from the specified string by no more than one character. With high, suggestions can differ by up to two characters. The default is none.
            SortExpression (string) --An expression that computes a score for each suggestion to control how they are sorted. The scores are rounded to the nearest integer, with a floor of 0 and a ceiling of 2^31-1. A document's relevance score is not computed for suggestions, so sort expressions cannot reference the _score value. To sort suggestions using a numeric field or existing expression, simply specify the name of the field or expression. If no expression is configured for the suggester, the suggestions are sorted with the closest matches listed first.
            
            
    :type Suggester: dict
    """
    pass

def delete_analysis_scheme(DomainName=None, AnalysisSchemeName=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param AnalysisSchemeName: [REQUIRED]
            The name of the analysis scheme you want to delete.
            
    :type AnalysisSchemeName: string
    """
    pass

def delete_domain(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            The name of the domain you want to permanently delete.
            Return typedict
            ReturnsResponse Syntax{
              'DomainStatus': {
                'DomainId': 'string',
                'DomainName': 'string',
                'ARN': 'string',
                'Created': True|False,
                'Deleted': True|False,
                'DocService': {
                  'Endpoint': 'string'
                },
                'SearchService': {
                  'Endpoint': 'string'
                },
                'RequiresIndexDocuments': True|False,
                'Processing': True|False,
                'SearchInstanceType': 'string',
                'SearchPartitionCount': 123,
                'SearchInstanceCount': 123,
                'Limits': {
                  'MaximumReplicationCount': 123,
                  'MaximumPartitionCount': 123
                }
              }
            }
            Response Structure
            (dict) --The result of a DeleteDomain request. Contains the status of a newly deleted domain, or no status if the domain has already been completely deleted.
            DomainStatus (dict) --The current status of the search domain.
            DomainId (string) --An internally generated unique identifier for a domain.
            DomainName (string) --A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            ARN (string) --The Amazon Resource Name (ARN) of the search domain. See Identifiers for IAM Entities in Using AWS Identity and Access Management for more information.
            Created (boolean) --True if the search domain is created. It can take several minutes to initialize a domain when CreateDomain is called. Newly created search domains are returned from DescribeDomains with a false value for Created until domain creation is complete.
            Deleted (boolean) --True if the search domain has been deleted. The system must clean up resources dedicated to the search domain when DeleteDomain is called. Newly deleted search domains are returned from DescribeDomains with a true value for IsDeleted for several minutes until resource cleanup is complete.
            DocService (dict) --The service endpoint for updating documents in a search domain.
            Endpoint (string) --The endpoint to which service requests can be submitted. For example, search-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com or doc-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com .
            SearchService (dict) --The service endpoint for requesting search results from a search domain.
            Endpoint (string) --The endpoint to which service requests can be submitted. For example, search-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com or doc-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com .
            RequiresIndexDocuments (boolean) --True if IndexDocuments needs to be called to activate the current domain configuration.
            Processing (boolean) --True if processing is being done to activate the current domain configuration.
            SearchInstanceType (string) --The instance type that is being used to process search requests.
            SearchPartitionCount (integer) --The number of partitions across which the search index is spread.
            SearchInstanceCount (integer) --The number of search instances that are available to process search requests.
            Limits (dict) --
            MaximumReplicationCount (integer) --
            MaximumPartitionCount (integer) --
            
            
            
    :type DomainName: string
    """
    pass

def delete_expression(DomainName=None, ExpressionName=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param ExpressionName: [REQUIRED]
            The name of the `` Expression`` to delete.
            
    :type ExpressionName: string
    """
    pass

def delete_index_field(DomainName=None, IndexFieldName=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param IndexFieldName: [REQUIRED]
            The name of the index field your want to remove from the domain's indexing options.
            
    :type IndexFieldName: string
    """
    pass

def delete_suggester(DomainName=None, SuggesterName=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param SuggesterName: [REQUIRED]
            Specifies the name of the suggester you want to delete.
            
    :type SuggesterName: string
    """
    pass

def describe_analysis_schemes(DomainName=None, AnalysisSchemeNames=None, Deployed=None):
    """
    :param DomainName: [REQUIRED]
            The name of the domain you want to describe.
            
    :type DomainName: string
    :param AnalysisSchemeNames: The analysis schemes you want to describe.
            (string) --Names must begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore).
            
    :type AnalysisSchemeNames: list
    :param Deployed: Whether to display the deployed configuration (true ) or include any pending changes (false ). Defaults to false .
    :type Deployed: boolean
    """
    pass

def describe_availability_options(DomainName=None, Deployed=None):
    """
    :param DomainName: [REQUIRED]
            The name of the domain you want to describe.
            
    :type DomainName: string
    :param Deployed: Whether to display the deployed configuration (true ) or include any pending changes (false ). Defaults to false .
    :type Deployed: boolean
    """
    pass

def describe_domains(DomainNames=None):
    """
    :param DomainNames: The names of the domains you want to include in the response.
            (string) --A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            Return typedict
            ReturnsResponse Syntax{
              'DomainStatusList': [
                {
                  'DomainId': 'string',
                  'DomainName': 'string',
                  'ARN': 'string',
                  'Created': True|False,
                  'Deleted': True|False,
                  'DocService': {
                    'Endpoint': 'string'
                  },
                  'SearchService': {
                    'Endpoint': 'string'
                  },
                  'RequiresIndexDocuments': True|False,
                  'Processing': True|False,
                  'SearchInstanceType': 'string',
                  'SearchPartitionCount': 123,
                  'SearchInstanceCount': 123,
                  'Limits': {
                    'MaximumReplicationCount': 123,
                    'MaximumPartitionCount': 123
                  }
                },
              ]
            }
            Response Structure
            (dict) --The result of a DescribeDomains request. Contains the status of the domains specified in the request or all domains owned by the account.
            DomainStatusList (list) --A list that contains the status of each requested domain.
            (dict) --The current status of the search domain.
            DomainId (string) --An internally generated unique identifier for a domain.
            DomainName (string) --A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            ARN (string) --The Amazon Resource Name (ARN) of the search domain. See Identifiers for IAM Entities in Using AWS Identity and Access Management for more information.
            Created (boolean) --True if the search domain is created. It can take several minutes to initialize a domain when CreateDomain is called. Newly created search domains are returned from DescribeDomains with a false value for Created until domain creation is complete.
            Deleted (boolean) --True if the search domain has been deleted. The system must clean up resources dedicated to the search domain when DeleteDomain is called. Newly deleted search domains are returned from DescribeDomains with a true value for IsDeleted for several minutes until resource cleanup is complete.
            DocService (dict) --The service endpoint for updating documents in a search domain.
            Endpoint (string) --The endpoint to which service requests can be submitted. For example, search-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com or doc-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com .
            SearchService (dict) --The service endpoint for requesting search results from a search domain.
            Endpoint (string) --The endpoint to which service requests can be submitted. For example, search-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com or doc-imdb-movies-oopcnjfn6ugofer3zx5iadxxca.eu-west-1.cloudsearch.amazonaws.com .
            RequiresIndexDocuments (boolean) --True if IndexDocuments needs to be called to activate the current domain configuration.
            Processing (boolean) --True if processing is being done to activate the current domain configuration.
            SearchInstanceType (string) --The instance type that is being used to process search requests.
            SearchPartitionCount (integer) --The number of partitions across which the search index is spread.
            SearchInstanceCount (integer) --The number of search instances that are available to process search requests.
            Limits (dict) --
            MaximumReplicationCount (integer) --
            MaximumPartitionCount (integer) --
            
            
            
    :type DomainNames: list
    """
    pass

def describe_expressions(DomainName=None, ExpressionNames=None, Deployed=None):
    """
    :param DomainName: [REQUIRED]
            The name of the domain you want to describe.
            
    :type DomainName: string
    :param ExpressionNames: Limits the `` DescribeExpressions`` response to the specified expressions. If not specified, all expressions are shown.
            (string) --Names must begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore).
            
    :type ExpressionNames: list
    :param Deployed: Whether to display the deployed configuration (true ) or include any pending changes (false ). Defaults to false .
    :type Deployed: boolean
    """
    pass

def describe_index_fields(DomainName=None, FieldNames=None, Deployed=None):
    """
    :param DomainName: [REQUIRED]
            The name of the domain you want to describe.
            
    :type DomainName: string
    :param FieldNames: A list of the index fields you want to describe. If not specified, information is returned for all configured index fields.
            (string) --
            
    :type FieldNames: list
    :param Deployed: Whether to display the deployed configuration (true ) or include any pending changes (false ). Defaults to false .
    :type Deployed: boolean
    """
    pass

def describe_scaling_parameters(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            Return typedict
            ReturnsResponse Syntax{
              'ScalingParameters': {
                'Options': {
                  'DesiredInstanceType': 'search.m1.small'|'search.m1.large'|'search.m2.xlarge'|'search.m2.2xlarge'|'search.m3.medium'|'search.m3.large'|'search.m3.xlarge'|'search.m3.2xlarge',
                  'DesiredReplicationCount': 123,
                  'DesiredPartitionCount': 123
                },
                'Status': {
                  'CreationDate': datetime(2015, 1, 1),
                  'UpdateDate': datetime(2015, 1, 1),
                  'UpdateVersion': 123,
                  'State': 'RequiresIndexDocuments'|'Processing'|'Active'|'FailedToValidate',
                  'PendingDeletion': True|False
                }
              }
            }
            Response Structure
            (dict) --The result of a DescribeScalingParameters request. Contains the scaling parameters configured for the domain specified in the request.
            ScalingParameters (dict) --The status and configuration of a search domain's scaling parameters.
            Options (dict) --The desired instance type and desired number of replicas of each index partition.
            DesiredInstanceType (string) --The instance type that you want to preconfigure for your domain. For example, search.m1.small .
            DesiredReplicationCount (integer) --The number of replicas you want to preconfigure for each index partition.
            DesiredPartitionCount (integer) --The number of partitions you want to preconfigure for your domain. Only valid when you select m2.2xlarge as the desired instance type.
            Status (dict) --The status of domain configuration option.
            CreationDate (datetime) --A timestamp for when this option was created.
            UpdateDate (datetime) --A timestamp for when this option was last updated.
            UpdateVersion (integer) --A unique integer that indicates when this option was last updated.
            State (string) --The state of processing a change to an option. Possible values:
            RequiresIndexDocuments : the option's latest value will not be deployed until IndexDocuments has been called and indexing is complete.
            Processing : the option's latest value is in the process of being activated.
            Active : the option's latest value is completely deployed.
            FailedToValidate : the option value is not compatible with the domain's data and cannot be used to index the data. You must either modify the option value or update or remove the incompatible documents.
            PendingDeletion (boolean) --Indicates that the option will be deleted once processing is complete.
            
            
            
    :type DomainName: string
    """
    pass

def describe_service_access_policies(DomainName=None, Deployed=None):
    """
    :param DomainName: [REQUIRED]
            The name of the domain you want to describe.
            
    :type DomainName: string
    :param Deployed: Whether to display the deployed configuration (true ) or include any pending changes (false ). Defaults to false .
    :type Deployed: boolean
    """
    pass

def describe_suggesters(DomainName=None, SuggesterNames=None, Deployed=None):
    """
    :param DomainName: [REQUIRED]
            The name of the domain you want to describe.
            
    :type DomainName: string
    :param SuggesterNames: The suggesters you want to describe.
            (string) --Names must begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore).
            
    :type SuggesterNames: list
    :param Deployed: Whether to display the deployed configuration (true ) or include any pending changes (false ). Defaults to false .
    :type Deployed: boolean
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def index_documents(DomainName=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            Return typedict
            ReturnsResponse Syntax{
              'FieldNames': [
                'string',
              ]
            }
            Response Structure
            (dict) --The result of an IndexDocuments request. Contains the status of the indexing operation, including the fields being indexed.
            FieldNames (list) --The names of the fields that are currently being indexed.
            (string) --A string that represents the name of an index field. CloudSearch supports regular index fields as well as dynamic fields. A dynamic field's name defines a pattern that begins or ends with a wildcard. Any document fields that don't map to a regular index field but do match a dynamic field's pattern are configured with the dynamic field's indexing options.
            Regular field names begin with a letter and can contain the following characters: a-z (lowercase), 0-9, and _ (underscore). Dynamic field names must begin or end with a wildcard (*). The wildcard can also be the only character in a dynamic field name. Multiple wildcards, and wildcards embedded within a string are not supported.
            The name score is reserved and cannot be used as a field name. To reference a document's ID, you can use the name _id .
            
            
            
    :type DomainName: string
    """
    pass

def list_domain_names():
    """
    """
    pass

def update_availability_options(DomainName=None, MultiAZ=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param MultiAZ: [REQUIRED]
            You expand an existing search domain to a second Availability Zone by setting the Multi-AZ option to true. Similarly, you can turn off the Multi-AZ option to downgrade the domain to a single Availability Zone by setting the Multi-AZ option to false .
            
    :type MultiAZ: boolean
    """
    pass

def update_scaling_parameters(DomainName=None, ScalingParameters=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param ScalingParameters: [REQUIRED]
            The desired instance type and desired number of replicas of each index partition.
            DesiredInstanceType (string) --The instance type that you want to preconfigure for your domain. For example, search.m1.small .
            DesiredReplicationCount (integer) --The number of replicas you want to preconfigure for each index partition.
            DesiredPartitionCount (integer) --The number of partitions you want to preconfigure for your domain. Only valid when you select m2.2xlarge as the desired instance type.
            
    :type ScalingParameters: dict
    """
    pass

def update_service_access_policies(DomainName=None, AccessPolicies=None):
    """
    :param DomainName: [REQUIRED]
            A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
            
    :type DomainName: string
    :param AccessPolicies: [REQUIRED]
            The access rules you want to configure. These rules replace any existing rules.
            
    :type AccessPolicies: string
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def add_tags_to_resource(ResourceArn=None, TagList=None):
    """
    :param ResourceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the AWS CloudHSM resource to tag.
            
    :type ResourceArn: string
    :param TagList: [REQUIRED]
            One or more tags.
            (dict) --A key-value pair that identifies or specifies metadata about an AWS CloudHSM resource.
            Key (string) -- [REQUIRED]The key of the tag.
            Value (string) -- [REQUIRED]The value of the tag.
            
            
    :type TagList: list
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def create_hapg(Label=None):
    """
    :param Label: [REQUIRED]
            The label of the new high-availability partition group.
            Return typedict
            ReturnsResponse Syntax{
              'HapgArn': 'string'
            }
            Response Structure
            (dict) --Contains the output of the CreateHAPartitionGroup action.
            HapgArn (string) --The ARN of the high-availability partition group.
            
            
    :type Label: string
    """
    pass

def create_hsm(SubnetId=None, SshKey=None, EniIp=None, IamRoleArn=None, ExternalId=None, SubscriptionType=None, ClientToken=None, SyslogIp=None):
    """
    :param SubnetId: [REQUIRED]
            The identifier of the subnet in your VPC in which to place the HSM.
            
    :type SubnetId: string
    :param SshKey: [REQUIRED]
            The SSH public key to install on the HSM.
            
    :type SshKey: string
    :param EniIp: The IP address to assign to the HSM's ENI.
            If an IP address is not specified, an IP address will be randomly chosen from the CIDR range of the subnet.
            
    :type EniIp: string
    :param IamRoleArn: [REQUIRED]
            The ARN of an IAM role to enable the AWS CloudHSM service to allocate an ENI on your behalf.
            
    :type IamRoleArn: string
    :param ExternalId: The external ID from IamRoleArn , if present.
    :type ExternalId: string
    :param SubscriptionType: [REQUIRED]
            Specifies the type of subscription for the HSM.
            PRODUCTION - The HSM is being used in a production environment.
            TRIAL - The HSM is being used in a product trial.
            
    :type SubscriptionType: string
    :param ClientToken: A user-defined token to ensure idempotence. Subsequent calls to this operation with the same token will be ignored.
    :type ClientToken: string
    :param SyslogIp: The IP address for the syslog monitoring server. The AWS CloudHSM service only supports one syslog monitoring server.
    :type SyslogIp: string
    """
    pass

def create_luna_client(Label=None, Certificate=None):
    """
    :param Label: The label for the client.
    :type Label: string
    :param Certificate: [REQUIRED]
            The contents of a Base64-Encoded X.509 v3 certificate to be installed on the HSMs used by this client.
            
    :type Certificate: string
    """
    pass

def delete_hapg(HapgArn=None):
    """
    :param HapgArn: [REQUIRED]
            The ARN of the high-availability partition group to delete.
            Return typedict
            ReturnsResponse Syntax{
              'Status': 'string'
            }
            Response Structure
            (dict) --Contains the output of the DeleteHapg action.
            Status (string) --The status of the action.
            
            
    :type HapgArn: string
    """
    pass

def delete_hsm(HsmArn=None):
    """
    :param HsmArn: [REQUIRED]
            The ARN of the HSM to delete.
            Return typedict
            ReturnsResponse Syntax{
              'Status': 'string'
            }
            Response Structure
            (dict) --Contains the output of the DeleteHsm operation.
            Status (string) --The status of the operation.
            
            
    :type HsmArn: string
    """
    pass

def delete_luna_client(ClientArn=None):
    """
    :param ClientArn: [REQUIRED]
            The ARN of the client to delete.
            Return typedict
            ReturnsResponse Syntax{
              'Status': 'string'
            }
            Response Structure
            (dict) --
            Status (string) --The status of the action.
            
            
    :type ClientArn: string
    """
    pass

def describe_hapg(HapgArn=None):
    """
    :param HapgArn: [REQUIRED]
            The ARN of the high-availability partition group to describe.
            Return typedict
            ReturnsResponse Syntax{
              'HapgArn': 'string',
              'HapgSerial': 'string',
              'HsmsLastActionFailed': [
                'string',
              ],
              'HsmsPendingDeletion': [
                'string',
              ],
              'HsmsPendingRegistration': [
                'string',
              ],
              'Label': 'string',
              'LastModifiedTimestamp': 'string',
              'PartitionSerialList': [
                'string',
              ],
              'State': 'READY'|'UPDATING'|'DEGRADED'
            }
            Response Structure
            (dict) --Contains the output of the DescribeHapg action.
            HapgArn (string) --The ARN of the high-availability partition group.
            HapgSerial (string) --The serial number of the high-availability partition group.
            HsmsLastActionFailed (list) --Contains a list of ARNs that identify the HSMs.
            (string) --An ARN that identifies an HSM.
            HsmsPendingDeletion (list) --Contains a list of ARNs that identify the HSMs.
            (string) --An ARN that identifies an HSM.
            HsmsPendingRegistration (list) --Contains a list of ARNs that identify the HSMs.
            (string) --An ARN that identifies an HSM.
            Label (string) --The label for the high-availability partition group.
            LastModifiedTimestamp (string) --The date and time the high-availability partition group was last modified.
            PartitionSerialList (list) --The list of partition serial numbers that belong to the high-availability partition group.
            (string) --
            State (string) --The state of the high-availability partition group.
            
            
    :type HapgArn: string
    """
    pass

def describe_hsm(HsmArn=None, HsmSerialNumber=None):
    """
    :param HsmArn: The ARN of the HSM. Either the HsmArn or the SerialNumber parameter must be specified.
    :type HsmArn: string
    :param HsmSerialNumber: The serial number of the HSM. Either the HsmArn or the HsmSerialNumber parameter must be specified.
    :type HsmSerialNumber: string
    """
    pass

def describe_luna_client(ClientArn=None, CertificateFingerprint=None):
    """
    :param ClientArn: The ARN of the client.
    :type ClientArn: string
    :param CertificateFingerprint: The certificate fingerprint.
    :type CertificateFingerprint: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_config(ClientArn=None, ClientVersion=None, HapgList=None):
    """
    :param ClientArn: [REQUIRED]
            The ARN of the client.
            
    :type ClientArn: string
    :param ClientVersion: [REQUIRED]
            The client version.
            
    :type ClientVersion: string
    :param HapgList: [REQUIRED]
            A list of ARNs that identify the high-availability partition groups that are associated with the client.
            (string) --
            
    :type HapgList: list
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_available_zones():
    """
    """
    pass

def list_hapgs(NextToken=None):
    """
    :param NextToken: The NextToken value from a previous call to ListHapgs . Pass null if this is the first call.
            Return typedict
            ReturnsResponse Syntax{
              'HapgList': [
                'string',
              ],
              'NextToken': 'string'
            }
            Response Structure
            (dict) --
            HapgList (list) --The list of high-availability partition groups.
            (string) --
            NextToken (string) --If not null, more results are available. Pass this value to ListHapgs to retrieve the next set of items.
            
            
    :type NextToken: string
    """
    pass

def list_hsms(NextToken=None):
    """
    :param NextToken: The NextToken value from a previous call to ListHsms . Pass null if this is the first call.
            Return typedict
            ReturnsResponse Syntax{
              'HsmList': [
                'string',
              ],
              'NextToken': 'string'
            }
            Response Structure
            (dict) --Contains the output of the ListHsms operation.
            HsmList (list) --The list of ARNs that identify the HSMs.
            (string) --An ARN that identifies an HSM.
            NextToken (string) --If not null, more results are available. Pass this value to ListHsms to retrieve the next set of items.
            
            
    :type NextToken: string
    """
    pass

def list_luna_clients(NextToken=None):
    """
    :param NextToken: The NextToken value from a previous call to ListLunaClients . Pass null if this is the first call.
            Return typedict
            ReturnsResponse Syntax{
              'ClientList': [
                'string',
              ],
              'NextToken': 'string'
            }
            Response Structure
            (dict) --
            ClientList (list) --The list of clients.
            (string) --
            NextToken (string) --If not null, more results are available. Pass this to ListLunaClients to retrieve the next set of items.
            
            
    :type NextToken: string
    """
    pass

def list_tags_for_resource(ResourceArn=None):
    """
    :param ResourceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the AWS CloudHSM resource.
            Return typedict
            ReturnsResponse Syntax{
              'TagList': [
                {
                  'Key': 'string',
                  'Value': 'string'
                },
              ]
            }
            Response Structure
            (dict) --
            TagList (list) --One or more tags.
            (dict) --A key-value pair that identifies or specifies metadata about an AWS CloudHSM resource.
            Key (string) --The key of the tag.
            Value (string) --The value of the tag.
            
            
            
    :type ResourceArn: string
    """
    pass

def modify_hapg(HapgArn=None, Label=None, PartitionSerialList=None):
    """
    :param HapgArn: [REQUIRED]
            The ARN of the high-availability partition group to modify.
            
    :type HapgArn: string
    :param Label: The new label for the high-availability partition group.
    :type Label: string
    :param PartitionSerialList: The list of partition serial numbers to make members of the high-availability partition group.
            (string) --
            
    :type PartitionSerialList: list
    """
    pass

def modify_hsm(HsmArn=None, SubnetId=None, EniIp=None, IamRoleArn=None, ExternalId=None, SyslogIp=None):
    """
    :param HsmArn: [REQUIRED]
            The ARN of the HSM to modify.
            
    :type HsmArn: string
    :param SubnetId: The new identifier of the subnet that the HSM is in. The new subnet must be in the same Availability Zone as the current subnet.
    :type SubnetId: string
    :param EniIp: The new IP address for the elastic network interface (ENI) attached to the HSM.
            If the HSM is moved to a different subnet, and an IP address is not specified, an IP address will be randomly chosen from the CIDR range of the new subnet.
            
    :type EniIp: string
    :param IamRoleArn: The new IAM role ARN.
    :type IamRoleArn: string
    :param ExternalId: The new external ID.
    :type ExternalId: string
    :param SyslogIp: The new IP address for the syslog monitoring server. The AWS CloudHSM service only supports one syslog monitoring server.
    :type SyslogIp: string
    """
    pass

def modify_luna_client(ClientArn=None, Certificate=None):
    """
    :param ClientArn: [REQUIRED]
            The ARN of the client.
            
    :type ClientArn: string
    :param Certificate: [REQUIRED]
            The new certificate for the client.
            
    :type Certificate: string
    """
    pass

def remove_tags_from_resource(ResourceArn=None, TagKeyList=None):
    """
    :param ResourceArn: [REQUIRED]
            The Amazon Resource Name (ARN) of the AWS CloudHSM resource.
            
    :type ResourceArn: string
    :param TagKeyList: [REQUIRED]
            The tag key or keys to remove.
            Specify only the tag key to remove (not the value). To overwrite the value for an existing tag, use AddTagsToResource .
            (string) --
            
    :type TagKeyList: list
    """
    pass




"""
The MIT License (MIT)

Copyright (c) 2016 Gehad Shaat

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


def accept_certificate_transfer(certificateId=None, setAsActive=None):
    """
    :param certificateId: [REQUIRED]
            The ID of the certificate.
            
    :type certificateId: string
    :param setAsActive: Specifies whether the certificate is active.
    :type setAsActive: boolean
    """
    pass

def attach_principal_policy(policyName=None, principal=None):
    """
    :param policyName: [REQUIRED]
            The policy name.
            
    :type policyName: string
    :param principal: [REQUIRED]
            The principal, which can be a certificate ARN (as returned from the CreateCertificate operation) or an Amazon Cognito ID.
            
    :type principal: string
    """
    pass

def attach_thing_principal(thingName=None, principal=None):
    """
    :param thingName: [REQUIRED]
            The name of the thing.
            
    :type thingName: string
    :param principal: [REQUIRED]
            The principal, such as a certificate or other credential.
            
    :type principal: string
    """
    pass

def can_paginate(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            ReturnsTrue if the operation can be paginated,
            False otherwise.
            
    :type operation_name: string
    """
    pass

def cancel_certificate_transfer(certificateId=None):
    """
    :param certificateId: [REQUIRED]
            The ID of the certificate.
            ReturnsNone
            
    :type certificateId: string
    """
    pass

def create_certificate_from_csr(certificateSigningRequest=None, setAsActive=None):
    """
    :param certificateSigningRequest: [REQUIRED]
            The certificate signing request (CSR).
            
    :type certificateSigningRequest: string
    :param setAsActive: Specifies whether the certificate is active.
    :type setAsActive: boolean
    """
    pass

def create_keys_and_certificate(setAsActive=None):
    """
    :param setAsActive: Specifies whether the certificate is active.
            Return typedict
            ReturnsResponse Syntax{
              'certificateArn': 'string',
              'certificateId': 'string',
              'certificatePem': 'string',
              'keyPair': {
                'PublicKey': 'string',
                'PrivateKey': 'string'
              }
            }
            Response Structure
            (dict) --The output of the CreateKeysAndCertificate operation.
            certificateArn (string) --The ARN of the certificate.
            certificateId (string) --The ID of the certificate. AWS IoT issues a default subject name for the certificate (for example, AWS IoT Certificate).
            certificatePem (string) --The certificate data, in PEM format.
            keyPair (dict) --The generated key pair.
            PublicKey (string) --The public key.
            PrivateKey (string) --The private key.
            
            
            
    :type setAsActive: boolean
    """
    pass

def create_policy(policyName=None, policyDocument=None):
    """
    :param policyName: [REQUIRED]
            The policy name.
            
    :type policyName: string
    :param policyDocument: [REQUIRED]
            The JSON document that describes the policy. policyDocument must have a minimum length of 1, with a maximum length of 2048, excluding whitespace.
            
    :type policyDocument: string
    """
    pass

def create_policy_version(policyName=None, policyDocument=None, setAsDefault=None):
    """
    :param policyName: [REQUIRED]
            The policy name.
            
    :type policyName: string
    :param policyDocument: [REQUIRED]
            The JSON document that describes the policy. Minimum length of 1. Maximum length of 2048, excluding whitespaces
            
    :type policyDocument: string
    :param setAsDefault: Specifies whether the policy version is set as the default. When this parameter is true, the new policy version becomes the operative version (that is, the version that is in effect for the certificates to which the policy is attached).
    :type setAsDefault: boolean
    """
    pass

def create_thing(thingName=None, thingTypeName=None, attributePayload=None):
    """
    :param thingName: [REQUIRED]
            The name of the thing to create.
            
    :type thingName: string
    :param thingTypeName: The name of the thing type associated with the new thing.
    :type thingTypeName: string
    :param attributePayload: The attribute payload, which consists of up to three name/value pairs in a JSON document. For example:
            {\'attributes\':{\'string1\':\'string2\'}})
            attributes (dict) --A JSON string containing up to three key-value pair in JSON format. For example:
            {\'attributes\':{\'string1\':\'string2\'}})
            (string) --
            (string) -- An attribute value for an Thing. An empty or null value in Update means that existing value for that attribute should be deleted. Empty and null values in create are ignored.
            
            merge (boolean) --Specifies whether the list of attributes provided in the AttributePayload is merged with the attributes stored in the registry, instead of overwriting them.
            To remove an attribute, call UpdateThing with an empty attribute value.
            Note
            The merge attribute is only valid when calling UpdateThing .
            
    :type attributePayload: dict
    """
    pass

def create_thing_type(thingTypeName=None, thingTypeProperties=None):
    """
    :param thingTypeName: [REQUIRED]
            The name of the thing type.
            
    :type thingTypeName: string
    :param thingTypeProperties: The ThingTypeProperties for the thing type to create. It contains information about the new thing type including a description, and a list of searchable thing attribute names.
            thingTypeDescription (string) --The description of the thing type.
            searchableAttributes (list) --A list of searchable thing attribute names.
            (string) --
            
    :type thingTypeProperties: dict
    """
    pass

def create_topic_rule(ruleName=None, topicRulePayload=None):
    """
    :param ruleName: [REQUIRED]
            The name of the rule.
            
    :type ruleName: string
    :param topicRulePayload: [REQUIRED]
            The rule payload.
            sql (string) -- [REQUIRED]The SQL statement used to query the topic. For more information, see AWS IoT SQL Reference in the AWS IoT Developer Guide .
            description (string) --The description of the rule.
            actions (list) -- [REQUIRED]The actions associated with the rule.
            (dict) --Describes the actions associated with a rule.
            dynamoDB (dict) --Write to a DynamoDB table.
            tableName (string) -- [REQUIRED]The name of the DynamoDB table.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access to the DynamoDB table.
            operation (string) --The type of operation to be performed. This follows the substitution template, so it can be ${operation} , but the substitution must result in one of the following: INSERT , UPDATE , or DELETE .
            hashKeyField (string) -- [REQUIRED]The hash key name.
            hashKeyValue (string) -- [REQUIRED]The hash key value.
            hashKeyType (string) --The hash key type. Valid values are 'STRING' or 'NUMBER'
            rangeKeyField (string) --The range key name.
            rangeKeyValue (string) --The range key value.
            rangeKeyType (string) --The range key type. Valid values are 'STRING' or 'NUMBER'
            payloadField (string) --The action payload. This name can be customized.
            dynamoDBv2 (dict) --Write to a DynamoDB table. This is a new version of the DynamoDB action. It allows you to write each attribute in an MQTT message payload into a separate DynamoDB column.
            roleArn (string) --The ARN of the IAM role that grants access to the DynamoDB table.
            putItem (dict) --Specifies the DynamoDB table to which the message data will be written. For example:
            { 'dynamoDBv2': { 'roleArn': 'aws:iam:12341251:my-role' 'putItem': { 'tableName': 'my-table' } } }
            Each attribute in the message payload will be written to a separate column in the DynamoDB database.
            tableName (string) -- [REQUIRED]The table where the message data will be written
            
            lambda (dict) --Invoke a Lambda function.
            functionArn (string) -- [REQUIRED]The ARN of the Lambda function.
            sns (dict) --Publish to an Amazon SNS topic.
            targetArn (string) -- [REQUIRED]The ARN of the SNS topic.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access.
            messageFormat (string) --The message format of the message to publish. Optional. Accepted values are 'JSON' and 'RAW'. The default value of the attribute is 'RAW'. SNS uses this setting to determine if the payload should be parsed and relevant platform-specific bits of the payload should be extracted. To read more about SNS message formats, see http://docs.aws.amazon.com/sns/latest/dg/json-formats.html refer to their official documentation.
            sqs (dict) --Publish to an Amazon SQS queue.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access.
            queueUrl (string) -- [REQUIRED]The URL of the Amazon SQS queue.
            useBase64 (boolean) --Specifies whether to use Base64 encoding.
            kinesis (dict) --Write data to an Amazon Kinesis stream.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access to the Amazon Kinesis stream.
            streamName (string) -- [REQUIRED]The name of the Amazon Kinesis stream.
            partitionKey (string) --The partition key.
            republish (dict) --Publish to another MQTT topic.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access.
            topic (string) -- [REQUIRED]The name of the MQTT topic.
            s3 (dict) --Write to an Amazon S3 bucket.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access.
            bucketName (string) -- [REQUIRED]The Amazon S3 bucket.
            key (string) -- [REQUIRED]The object key.
            cannedAcl (string) --The Amazon S3 canned ACL that controls access to the object identified by the object key. For more information, see S3 canned ACLs .
            firehose (dict) --Write to an Amazon Kinesis Firehose stream.
            roleArn (string) -- [REQUIRED]The IAM role that grants access to the Amazon Kinesis Firehost stream.
            deliveryStreamName (string) -- [REQUIRED]The delivery stream name.
            separator (string) --A character separator that will be used to separate records written to the Firehose stream. Valid values are: 'n' (newline), 't' (tab), 'rn' (Windows newline), ',' (comma).
            cloudwatchMetric (dict) --Capture a CloudWatch metric.
            roleArn (string) -- [REQUIRED]The IAM role that allows access to the CloudWatch metric.
            metricNamespace (string) -- [REQUIRED]The CloudWatch metric namespace name.
            metricName (string) -- [REQUIRED]The CloudWatch metric name.
            metricValue (string) -- [REQUIRED]The CloudWatch metric value.
            metricUnit (string) -- [REQUIRED]The metric unit supported by CloudWatch.
            metricTimestamp (string) --An optional Unix timestamp .
            cloudwatchAlarm (dict) --Change the state of a CloudWatch alarm.
            roleArn (string) -- [REQUIRED]The IAM role that allows access to the CloudWatch alarm.
            alarmName (string) -- [REQUIRED]The CloudWatch alarm name.
            stateReason (string) -- [REQUIRED]The reason for the alarm change.
            stateValue (string) -- [REQUIRED]The value of the alarm state. Acceptable values are: OK, ALARM, INSUFFICIENT_DATA.
            elasticsearch (dict) --Write data to an Amazon Elasticsearch Service domain.
            roleArn (string) -- [REQUIRED]The IAM role ARN that has access to Elasticsearch.
            endpoint (string) -- [REQUIRED]The endpoint of your Elasticsearch domain.
            index (string) -- [REQUIRED]The Elasticsearch index where you want to store your data.
            type (string) -- [REQUIRED]The type of document you are storing.
            id (string) -- [REQUIRED]The unique identifier for the document you are storing.
            
            ruleDisabled (boolean) --Specifies whether the rule is disabled.
            awsIotSqlVersion (string) --The version of the SQL rules engine to use when evaluating the rule.
            
    :type topicRulePayload: dict
    """
    pass

def delete_ca_certificate(certificateId=None):
    """
    :param certificateId: [REQUIRED]
            The ID of the certificate to delete.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --The output for the DeleteCACertificate operation.
            
            
    :type certificateId: string
    """
    pass

def delete_certificate(certificateId=None):
    """
    :param certificateId: [REQUIRED]
            The ID of the certificate.
            ReturnsNone
            
    :type certificateId: string
    """
    pass

def delete_policy(policyName=None):
    """
    :param policyName: [REQUIRED]
            The name of the policy to delete.
            ReturnsNone
            
    :type policyName: string
    """
    pass

def delete_policy_version(policyName=None, policyVersionId=None):
    """
    :param policyName: [REQUIRED]
            The name of the policy.
            
    :type policyName: string
    :param policyVersionId: [REQUIRED]
            The policy version ID.
            
    :type policyVersionId: string
    """
    pass

def delete_registration_code():
    """
    """
    pass

def delete_thing(thingName=None, expectedVersion=None):
    """
    :param thingName: [REQUIRED]
            The name of the thing to delete.
            
    :type thingName: string
    :param expectedVersion: The expected version of the thing record in the registry. If the version of the record in the registry does not match the expected version specified in the request, the DeleteThing request is rejected with a VersionConflictException .
    :type expectedVersion: integer
    """
    pass

def delete_thing_type(thingTypeName=None):
    """
    :param thingTypeName: [REQUIRED]
            The name of the thing type.
            Return typedict
            ReturnsResponse Syntax{}
            Response Structure
            (dict) --The output for the DeleteThingType operation.
            
            
    :type thingTypeName: string
    """
    pass

def delete_topic_rule(ruleName=None):
    """
    :param ruleName: [REQUIRED]
            The name of the rule.
            ReturnsNone
            
    :type ruleName: string
    """
    pass

def deprecate_thing_type(thingTypeName=None, undoDeprecate=None):
    """
    :param thingTypeName: [REQUIRED]
            The name of the thing type to deprecate.
            
    :type thingTypeName: string
    :param undoDeprecate: Whether to undeprecate a deprecated thing type. If true , the thing type will not be deprecated anymore and you can associate it with things.
    :type undoDeprecate: boolean
    """
    pass

def describe_ca_certificate(certificateId=None):
    """
    :param certificateId: [REQUIRED]
            The CA certificate identifier.
            Return typedict
            ReturnsResponse Syntax{
              'certificateDescription': {
                'certificateArn': 'string',
                'certificateId': 'string',
                'status': 'ACTIVE'|'INACTIVE',
                'certificatePem': 'string',
                'ownedBy': 'string',
                'creationDate': datetime(2015, 1, 1),
                'autoRegistrationStatus': 'ENABLE'|'DISABLE'
              }
            }
            Response Structure
            (dict) --The output from the DescribeCACertificate operation.
            certificateDescription (dict) --The CA certificate description.
            certificateArn (string) --The CA certificate ARN.
            certificateId (string) --The CA certificate ID.
            status (string) --The status of a CA certificate.
            certificatePem (string) --The CA certificate data, in PEM format.
            ownedBy (string) --The owner of the CA certificate.
            creationDate (datetime) --The date the CA certificate was created.
            autoRegistrationStatus (string) --Whether the CA certificate configured for auto registration of device certificates. Valid values are 'ENABLE' and 'DISABLE'
            
            
            
    :type certificateId: string
    """
    pass

def describe_certificate(certificateId=None):
    """
    :param certificateId: [REQUIRED]
            The ID of the certificate.
            Return typedict
            ReturnsResponse Syntax{
              'certificateDescription': {
                'certificateArn': 'string',
                'certificateId': 'string',
                'caCertificateId': 'string',
                'status': 'ACTIVE'|'INACTIVE'|'REVOKED'|'PENDING_TRANSFER'|'REGISTER_INACTIVE'|'PENDING_ACTIVATION',
                'certificatePem': 'string',
                'ownedBy': 'string',
                'previousOwnedBy': 'string',
                'creationDate': datetime(2015, 1, 1),
                'lastModifiedDate': datetime(2015, 1, 1),
                'transferData': {
                  'transferMessage': 'string',
                  'rejectReason': 'string',
                  'transferDate': datetime(2015, 1, 1),
                  'acceptDate': datetime(2015, 1, 1),
                  'rejectDate': datetime(2015, 1, 1)
                }
              }
            }
            Response Structure
            (dict) --The output of the DescribeCertificate operation.
            certificateDescription (dict) --The description of the certificate.
            certificateArn (string) --The ARN of the certificate.
            certificateId (string) --The ID of the certificate.
            caCertificateId (string) --The certificate ID of the CA certificate used to sign this certificate.
            status (string) --The status of the certificate.
            certificatePem (string) --The certificate data, in PEM format.
            ownedBy (string) --The ID of the AWS account that owns the certificate.
            previousOwnedBy (string) --The ID of the AWS account of the previous owner of the certificate.
            creationDate (datetime) --The date and time the certificate was created.
            lastModifiedDate (datetime) --The date and time the certificate was last modified.
            transferData (dict) --The transfer data.
            transferMessage (string) --The transfer message.
            rejectReason (string) --The reason why the transfer was rejected.
            transferDate (datetime) --The date the transfer took place.
            acceptDate (datetime) --The date the transfer was accepted.
            rejectDate (datetime) --The date the transfer was rejected.
            
            
            
    :type certificateId: string
    """
    pass

def describe_endpoint():
    """
    """
    pass

def describe_thing(thingName=None):
    """
    :param thingName: [REQUIRED]
            The name of the thing.
            Return typedict
            ReturnsResponse Syntax{
              'defaultClientId': 'string',
              'thingName': 'string',
              'thingTypeName': 'string',
              'attributes': {
                'string': 'string'
              },
              'version': 123
            }
            Response Structure
            (dict) --The output from the DescribeThing operation.
            defaultClientId (string) --The default client ID.
            thingName (string) --The name of the thing.
            thingTypeName (string) --The thing type name.
            attributes (dict) --The thing attributes.
            (string) --
            (string) -- An attribute value for an Thing. An empty or null value in Update means that existing value for that attribute should be deleted. Empty and null values in create are ignored.
            
            version (integer) --The current version of the thing record in the registry.
            Note
            To avoid unintentional changes to the information in the registry, you can pass the version information in the expectedVersion parameter of the UpdateThing and DeleteThing calls.
            
            
    :type thingName: string
    """
    pass

def describe_thing_type(thingTypeName=None):
    """
    :param thingTypeName: [REQUIRED]
            The name of the thing type.
            Return typedict
            ReturnsResponse Syntax{
              'thingTypeName': 'string',
              'thingTypeProperties': {
                'thingTypeDescription': 'string',
                'searchableAttributes': [
                  'string',
                ]
              },
              'thingTypeMetadata': {
                'deprecated': True|False,
                'deprecationDate': datetime(2015, 1, 1),
                'creationDate': datetime(2015, 1, 1)
              }
            }
            Response Structure
            (dict) --The output for the DescribeThingType operation.
            thingTypeName (string) --The name of the thing type.
            thingTypeProperties (dict) --The ThingTypeProperties contains information about the thing type including description, and a list of searchable thing attribute names.
            thingTypeDescription (string) --The description of the thing type.
            searchableAttributes (list) --A list of searchable thing attribute names.
            (string) --
            
            thingTypeMetadata (dict) --The ThingTypeMetadata contains additional information about the thing type including: creation date and time, a value indicating whether the thing type is deprecated, and a date and time when time was deprecated.
            deprecated (boolean) --Whether the thing type is deprecated. If true , no new things could be associated with this type.
            deprecationDate (datetime) --The date and time when the thing type was deprecated.
            creationDate (datetime) --The date and time when the thing type was created.
            
            
            
    :type thingTypeName: string
    """
    pass

def detach_principal_policy(policyName=None, principal=None):
    """
    :param policyName: [REQUIRED]
            The name of the policy to detach.
            
    :type policyName: string
    :param principal: [REQUIRED]
            The principal.
            If the principal is a certificate, specify the certificate ARN. If the principal is an Amazon Cognito identity, specify the identity ID.
            
    :type principal: string
    """
    pass

def detach_thing_principal(thingName=None, principal=None):
    """
    :param thingName: [REQUIRED]
            The name of the thing.
            
    :type thingName: string
    :param principal: [REQUIRED]
            If the principal is a certificate, this value must be ARN of the certificate. If the principal is an Amazon Cognito identity, this value must be the ID of the Amazon Cognito identity.
            
    :type principal: string
    """
    pass

def disable_topic_rule(ruleName=None):
    """
    :param ruleName: [REQUIRED]
            The name of the rule to disable.
            ReturnsNone
            
    :type ruleName: string
    """
    pass

def enable_topic_rule(ruleName=None):
    """
    :param ruleName: [REQUIRED]
            The name of the topic rule to enable.
            ReturnsNone
            
    :type ruleName: string
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    :param ClientMethod: The client method to presign for
    :type ClientMethod: string
    :param Params: The parameters normally passed to
            ClientMethod.
    :type Params: dict
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)
    :type ExpiresIn: int
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.
    :type HttpMethod: string
    """
    pass

def get_logging_options():
    """
    """
    pass

def get_paginator(operation_name=None):
    """
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').
            Raises OperationNotPageableErrorRaised if the operation is not
            pageable. You can use the client.can_paginate method to
            check if an operation is pageable.
            Return typeL{botocore.paginate.Paginator}
            ReturnsA paginator object.
            
    :type operation_name: string
    """
    pass

def get_policy(policyName=None):
    """
    :param policyName: [REQUIRED]
            The name of the policy.
            Return typedict
            ReturnsResponse Syntax{
              'policyName': 'string',
              'policyArn': 'string',
              'policyDocument': 'string',
              'defaultVersionId': 'string'
            }
            Response Structure
            (dict) --The output from the GetPolicy operation.
            policyName (string) --The policy name.
            policyArn (string) --The policy ARN.
            policyDocument (string) --The JSON document that describes the policy.
            defaultVersionId (string) --The default policy version ID.
            
            
    :type policyName: string
    """
    pass

def get_policy_version(policyName=None, policyVersionId=None):
    """
    :param policyName: [REQUIRED]
            The name of the policy.
            
    :type policyName: string
    :param policyVersionId: [REQUIRED]
            The policy version ID.
            
    :type policyVersionId: string
    """
    pass

def get_registration_code():
    """
    """
    pass

def get_topic_rule(ruleName=None):
    """
    :param ruleName: [REQUIRED]
            The name of the rule.
            Return typedict
            ReturnsResponse Syntax{
              'ruleArn': 'string',
              'rule': {
                'ruleName': 'string',
                'sql': 'string',
                'description': 'string',
                'createdAt': datetime(2015, 1, 1),
                'actions': [
                  {
                    'dynamoDB': {
                      'tableName': 'string',
                      'roleArn': 'string',
                      'operation': 'string',
                      'hashKeyField': 'string',
                      'hashKeyValue': 'string',
                      'hashKeyType': 'STRING'|'NUMBER',
                      'rangeKeyField': 'string',
                      'rangeKeyValue': 'string',
                      'rangeKeyType': 'STRING'|'NUMBER',
                      'payloadField': 'string'
                    },
                    'dynamoDBv2': {
                      'roleArn': 'string',
                      'putItem': {
                        'tableName': 'string'
                      }
                    },
                    'lambda': {
                      'functionArn': 'string'
                    },
                    'sns': {
                      'targetArn': 'string',
                      'roleArn': 'string',
                      'messageFormat': 'RAW'|'JSON'
                    },
                    'sqs': {
                      'roleArn': 'string',
                      'queueUrl': 'string',
                      'useBase64': True|False
                    },
                    'kinesis': {
                      'roleArn': 'string',
                      'streamName': 'string',
                      'partitionKey': 'string'
                    },
                    'republish': {
                      'roleArn': 'string',
                      'topic': 'string'
                    },
                    's3': {
                      'roleArn': 'string',
                      'bucketName': 'string',
                      'key': 'string',
                      'cannedAcl': 'private'|'public-read'|'public-read-write'|'aws-exec-read'|'authenticated-read'|'bucket-owner-read'|'bucket-owner-full-control'|'log-delivery-write'
                    },
                    'firehose': {
                      'roleArn': 'string',
                      'deliveryStreamName': 'string',
                      'separator': 'string'
                    },
                    'cloudwatchMetric': {
                      'roleArn': 'string',
                      'metricNamespace': 'string',
                      'metricName': 'string',
                      'metricValue': 'string',
                      'metricUnit': 'string',
                      'metricTimestamp': 'string'
                    },
                    'cloudwatchAlarm': {
                      'roleArn': 'string',
                      'alarmName': 'string',
                      'stateReason': 'string',
                      'stateValue': 'string'
                    },
                    'elasticsearch': {
                      'roleArn': 'string',
                      'endpoint': 'string',
                      'index': 'string',
                      'type': 'string',
                      'id': 'string'
                    }
                  },
                ],
                'ruleDisabled': True|False,
                'awsIotSqlVersion': 'string'
              }
            }
            Response Structure
            (dict) --The output from the GetTopicRule operation.
            ruleArn (string) --The rule ARN.
            rule (dict) --The rule.
            ruleName (string) --The name of the rule.
            sql (string) --The SQL statement used to query the topic. When using a SQL query with multiple lines, be sure to escape the newline characters.
            description (string) --The description of the rule.
            createdAt (datetime) --The date and time the rule was created.
            actions (list) --The actions associated with the rule.
            (dict) --Describes the actions associated with a rule.
            dynamoDB (dict) --Write to a DynamoDB table.
            tableName (string) --The name of the DynamoDB table.
            roleArn (string) --The ARN of the IAM role that grants access to the DynamoDB table.
            operation (string) --The type of operation to be performed. This follows the substitution template, so it can be ${operation} , but the substitution must result in one of the following: INSERT , UPDATE , or DELETE .
            hashKeyField (string) --The hash key name.
            hashKeyValue (string) --The hash key value.
            hashKeyType (string) --The hash key type. Valid values are 'STRING' or 'NUMBER'
            rangeKeyField (string) --The range key name.
            rangeKeyValue (string) --The range key value.
            rangeKeyType (string) --The range key type. Valid values are 'STRING' or 'NUMBER'
            payloadField (string) --The action payload. This name can be customized.
            dynamoDBv2 (dict) --Write to a DynamoDB table. This is a new version of the DynamoDB action. It allows you to write each attribute in an MQTT message payload into a separate DynamoDB column.
            roleArn (string) --The ARN of the IAM role that grants access to the DynamoDB table.
            putItem (dict) --Specifies the DynamoDB table to which the message data will be written. For example:
            { 'dynamoDBv2': { 'roleArn': 'aws:iam:12341251:my-role' 'putItem': { 'tableName': 'my-table' } } }
            Each attribute in the message payload will be written to a separate column in the DynamoDB database.
            tableName (string) --The table where the message data will be written
            
            lambda (dict) --Invoke a Lambda function.
            functionArn (string) --The ARN of the Lambda function.
            sns (dict) --Publish to an Amazon SNS topic.
            targetArn (string) --The ARN of the SNS topic.
            roleArn (string) --The ARN of the IAM role that grants access.
            messageFormat (string) --The message format of the message to publish. Optional. Accepted values are 'JSON' and 'RAW'. The default value of the attribute is 'RAW'. SNS uses this setting to determine if the payload should be parsed and relevant platform-specific bits of the payload should be extracted. To read more about SNS message formats, see http://docs.aws.amazon.com/sns/latest/dg/json-formats.html refer to their official documentation.
            sqs (dict) --Publish to an Amazon SQS queue.
            roleArn (string) --The ARN of the IAM role that grants access.
            queueUrl (string) --The URL of the Amazon SQS queue.
            useBase64 (boolean) --Specifies whether to use Base64 encoding.
            kinesis (dict) --Write data to an Amazon Kinesis stream.
            roleArn (string) --The ARN of the IAM role that grants access to the Amazon Kinesis stream.
            streamName (string) --The name of the Amazon Kinesis stream.
            partitionKey (string) --The partition key.
            republish (dict) --Publish to another MQTT topic.
            roleArn (string) --The ARN of the IAM role that grants access.
            topic (string) --The name of the MQTT topic.
            s3 (dict) --Write to an Amazon S3 bucket.
            roleArn (string) --The ARN of the IAM role that grants access.
            bucketName (string) --The Amazon S3 bucket.
            key (string) --The object key.
            cannedAcl (string) --The Amazon S3 canned ACL that controls access to the object identified by the object key. For more information, see S3 canned ACLs .
            firehose (dict) --Write to an Amazon Kinesis Firehose stream.
            roleArn (string) --The IAM role that grants access to the Amazon Kinesis Firehost stream.
            deliveryStreamName (string) --The delivery stream name.
            separator (string) --A character separator that will be used to separate records written to the Firehose stream. Valid values are: 'n' (newline), 't' (tab), 'rn' (Windows newline), ',' (comma).
            cloudwatchMetric (dict) --Capture a CloudWatch metric.
            roleArn (string) --The IAM role that allows access to the CloudWatch metric.
            metricNamespace (string) --The CloudWatch metric namespace name.
            metricName (string) --The CloudWatch metric name.
            metricValue (string) --The CloudWatch metric value.
            metricUnit (string) --The metric unit supported by CloudWatch.
            metricTimestamp (string) --An optional Unix timestamp .
            cloudwatchAlarm (dict) --Change the state of a CloudWatch alarm.
            roleArn (string) --The IAM role that allows access to the CloudWatch alarm.
            alarmName (string) --The CloudWatch alarm name.
            stateReason (string) --The reason for the alarm change.
            stateValue (string) --The value of the alarm state. Acceptable values are: OK, ALARM, INSUFFICIENT_DATA.
            elasticsearch (dict) --Write data to an Amazon Elasticsearch Service domain.
            roleArn (string) --The IAM role ARN that has access to Elasticsearch.
            endpoint (string) --The endpoint of your Elasticsearch domain.
            index (string) --The Elasticsearch index where you want to store your data.
            type (string) --The type of document you are storing.
            id (string) --The unique identifier for the document you are storing.
            
            ruleDisabled (boolean) --Specifies whether the rule is disabled.
            awsIotSqlVersion (string) --The version of the SQL rules engine to use when evaluating the rule.
            
            
            
    :type ruleName: string
    """
    pass

def get_waiter():
    """
    """
    pass

def list_ca_certificates(pageSize=None, marker=None, ascendingOrder=None):
    """
    :param pageSize: The result page size.
    :type pageSize: integer
    :param marker: The marker for the next set of results.
    :type marker: string
    :param ascendingOrder: Determines the order of the results.
    :type ascendingOrder: boolean
    """
    pass

def list_certificates(pageSize=None, marker=None, ascendingOrder=None):
    """
    :param pageSize: The result page size.
    :type pageSize: integer
    :param marker: The marker for the next set of results.
    :type marker: string
    :param ascendingOrder: Specifies the order for results. If True, the results are returned in ascending order, based on the creation date.
    :type ascendingOrder: boolean
    """
    pass

def list_certificates_by_ca(caCertificateId=None, pageSize=None, marker=None, ascendingOrder=None):
    """
    :param caCertificateId: [REQUIRED]
            The ID of the CA certificate. This operation will list all registered device certificate that were signed by this CA certificate.
            
    :type caCertificateId: string
    :param pageSize: The result page size.
    :type pageSize: integer
    :param marker: The marker for the next set of results.
    :type marker: string
    :param ascendingOrder: Specifies the order for results. If True, the results are returned in ascending order, based on the creation date.
    :type ascendingOrder: boolean
    """
    pass

def list_outgoing_certificates(pageSize=None, marker=None, ascendingOrder=None):
    """
    :param pageSize: The result page size.
    :type pageSize: integer
    :param marker: The marker for the next set of results.
    :type marker: string
    :param ascendingOrder: Specifies the order for results. If True, the results are returned in ascending order, based on the creation date.
    :type ascendingOrder: boolean
    """
    pass

def list_policies(marker=None, pageSize=None, ascendingOrder=None):
    """
    :param marker: The marker for the next set of results.
    :type marker: string
    :param pageSize: The result page size.
    :type pageSize: integer
    :param ascendingOrder: Specifies the order for results. If true, the results are returned in ascending creation order.
    :type ascendingOrder: boolean
    """
    pass

def list_policy_principals(policyName=None, marker=None, pageSize=None, ascendingOrder=None):
    """
    :param policyName: [REQUIRED]
            The policy name.
            
    :type policyName: string
    :param marker: The marker for the next set of results.
    :type marker: string
    :param pageSize: The result page size.
    :type pageSize: integer
    :param ascendingOrder: Specifies the order for results. If true, the results are returned in ascending creation order.
    :type ascendingOrder: boolean
    """
    pass

def list_policy_versions(policyName=None):
    """
    :param policyName: [REQUIRED]
            The policy name.
            Return typedict
            ReturnsResponse Syntax{
              'policyVersions': [
                {
                  'versionId': 'string',
                  'isDefaultVersion': True|False,
                  'createDate': datetime(2015, 1, 1)
                },
              ]
            }
            Response Structure
            (dict) --The output from the ListPolicyVersions operation.
            policyVersions (list) --The policy versions.
            (dict) --Describes a policy version.
            versionId (string) --The policy version ID.
            isDefaultVersion (boolean) --Specifies whether the policy version is the default.
            createDate (datetime) --The date and time the policy was created.
            
            
            
    :type policyName: string
    """
    pass

def list_principal_policies(principal=None, marker=None, pageSize=None, ascendingOrder=None):
    """
    :param principal: [REQUIRED]
            The principal.
            
    :type principal: string
    :param marker: The marker for the next set of results.
    :type marker: string
    :param pageSize: The result page size.
    :type pageSize: integer
    :param ascendingOrder: Specifies the order for results. If true, results are returned in ascending creation order.
    :type ascendingOrder: boolean
    """
    pass

def list_principal_things(nextToken=None, maxResults=None, principal=None):
    """
    :param nextToken: The token for the next set of results, or null if there are no additional results.
    :type nextToken: string
    :param maxResults: The maximum number of results to return in this operation.
    :type maxResults: integer
    :param principal: [REQUIRED]
            The principal.
            
    :type principal: string
    """
    pass

def list_thing_principals(thingName=None):
    """
    :param thingName: [REQUIRED]
            The name of the thing.
            Return typedict
            ReturnsResponse Syntax{
              'principals': [
                'string',
              ]
            }
            Response Structure
            (dict) --The output from the ListThingPrincipals operation.
            principals (list) --The principals associated with the thing.
            (string) --
            
            
    :type thingName: string
    """
    pass

def list_thing_types(nextToken=None, maxResults=None, thingTypeName=None):
    """
    :param nextToken: The token for the next set of results, or null if there are no additional results.
    :type nextToken: string
    :param maxResults: The maximum number of results to return in this operation.
    :type maxResults: integer
    :param thingTypeName: The name of the thing type.
    :type thingTypeName: string
    """
    pass

def list_things(nextToken=None, maxResults=None, attributeName=None, attributeValue=None, thingTypeName=None):
    """
    :param nextToken: The token for the next set of results, or null if there are no additional results.
    :type nextToken: string
    :param maxResults: The maximum number of results to return in this operation.
    :type maxResults: integer
    :param attributeName: The attribute name used to search for things.
    :type attributeName: string
    :param attributeValue: The attribute value used to search for things.
    :type attributeValue: string
    :param thingTypeName: The name of the thing type used to search for things.
    :type thingTypeName: string
    """
    pass

def list_topic_rules(topic=None, maxResults=None, nextToken=None, ruleDisabled=None):
    """
    :param topic: The topic.
    :type topic: string
    :param maxResults: The maximum number of results to return.
    :type maxResults: integer
    :param nextToken: A token used to retrieve the next value.
    :type nextToken: string
    :param ruleDisabled: Specifies whether the rule is disabled.
    :type ruleDisabled: boolean
    """
    pass

def register_ca_certificate(caCertificate=None, verificationCertificate=None, setAsActive=None, allowAutoRegistration=None):
    """
    :param caCertificate: [REQUIRED]
            The CA certificate.
            
    :type caCertificate: string
    :param verificationCertificate: [REQUIRED]
            The private key verification certificate.
            
    :type verificationCertificate: string
    :param setAsActive: A boolean value that specifies if the CA certificate is set to active.
    :type setAsActive: boolean
    :param allowAutoRegistration: Allows this CA certificate to be used for auto registration of device certificates.
    :type allowAutoRegistration: boolean
    """
    pass

def register_certificate(certificatePem=None, caCertificatePem=None, setAsActive=None, status=None):
    """
    :param certificatePem: [REQUIRED]
            The certificate data, in PEM format.
            
    :type certificatePem: string
    :param caCertificatePem: The CA certificate used to sign the device certificate being registered.
    :type caCertificatePem: string
    :param setAsActive: A boolean value that specifies if the CA certificate is set to active.
    :type setAsActive: boolean
    :param status: 
    :type status: string
    """
    pass

def reject_certificate_transfer(certificateId=None, rejectReason=None):
    """
    :param certificateId: [REQUIRED]
            The ID of the certificate.
            
    :type certificateId: string
    :param rejectReason: The reason the certificate transfer was rejected.
    :type rejectReason: string
    """
    pass

def replace_topic_rule(ruleName=None, topicRulePayload=None):
    """
    :param ruleName: [REQUIRED]
            The name of the rule.
            
    :type ruleName: string
    :param topicRulePayload: [REQUIRED]
            The rule payload.
            sql (string) -- [REQUIRED]The SQL statement used to query the topic. For more information, see AWS IoT SQL Reference in the AWS IoT Developer Guide .
            description (string) --The description of the rule.
            actions (list) -- [REQUIRED]The actions associated with the rule.
            (dict) --Describes the actions associated with a rule.
            dynamoDB (dict) --Write to a DynamoDB table.
            tableName (string) -- [REQUIRED]The name of the DynamoDB table.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access to the DynamoDB table.
            operation (string) --The type of operation to be performed. This follows the substitution template, so it can be ${operation} , but the substitution must result in one of the following: INSERT , UPDATE , or DELETE .
            hashKeyField (string) -- [REQUIRED]The hash key name.
            hashKeyValue (string) -- [REQUIRED]The hash key value.
            hashKeyType (string) --The hash key type. Valid values are 'STRING' or 'NUMBER'
            rangeKeyField (string) --The range key name.
            rangeKeyValue (string) --The range key value.
            rangeKeyType (string) --The range key type. Valid values are 'STRING' or 'NUMBER'
            payloadField (string) --The action payload. This name can be customized.
            dynamoDBv2 (dict) --Write to a DynamoDB table. This is a new version of the DynamoDB action. It allows you to write each attribute in an MQTT message payload into a separate DynamoDB column.
            roleArn (string) --The ARN of the IAM role that grants access to the DynamoDB table.
            putItem (dict) --Specifies the DynamoDB table to which the message data will be written. For example:
            { 'dynamoDBv2': { 'roleArn': 'aws:iam:12341251:my-role' 'putItem': { 'tableName': 'my-table' } } }
            Each attribute in the message payload will be written to a separate column in the DynamoDB database.
            tableName (string) -- [REQUIRED]The table where the message data will be written
            
            lambda (dict) --Invoke a Lambda function.
            functionArn (string) -- [REQUIRED]The ARN of the Lambda function.
            sns (dict) --Publish to an Amazon SNS topic.
            targetArn (string) -- [REQUIRED]The ARN of the SNS topic.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access.
            messageFormat (string) --The message format of the message to publish. Optional. Accepted values are 'JSON' and 'RAW'. The default value of the attribute is 'RAW'. SNS uses this setting to determine if the payload should be parsed and relevant platform-specific bits of the payload should be extracted. To read more about SNS message formats, see http://docs.aws.amazon.com/sns/latest/dg/json-formats.html refer to their official documentation.
            sqs (dict) --Publish to an Amazon SQS queue.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access.
            queueUrl (string) -- [REQUIRED]The URL of the Amazon SQS queue.
            useBase64 (boolean) --Specifies whether to use Base64 encoding.
            kinesis (dict) --Write data to an Amazon Kinesis stream.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access to the Amazon Kinesis stream.
            streamName (string) -- [REQUIRED]The name of the Amazon Kinesis stream.
            partitionKey (string) --The partition key.
            republish (dict) --Publish to another MQTT topic.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access.
            topic (string) -- [REQUIRED]The name of the MQTT topic.
            s3 (dict) --Write to an Amazon S3 bucket.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access.
            bucketName (string) -- [REQUIRED]The Amazon S3 bucket.
            key (string) -- [REQUIRED]The object key.
            cannedAcl (string) --The Amazon S3 canned ACL that controls access to the object identified by the object key. For more information, see S3 canned ACLs .
            firehose (dict) --Write to an Amazon Kinesis Firehose stream.
            roleArn (string) -- [REQUIRED]The IAM role that grants access to the Amazon Kinesis Firehost stream.
            deliveryStreamName (string) -- [REQUIRED]The delivery stream name.
            separator (string) --A character separator that will be used to separate records written to the Firehose stream. Valid values are: 'n' (newline), 't' (tab), 'rn' (Windows newline), ',' (comma).
            cloudwatchMetric (dict) --Capture a CloudWatch metric.
            roleArn (string) -- [REQUIRED]The IAM role that allows access to the CloudWatch metric.
            metricNamespace (string) -- [REQUIRED]The CloudWatch metric namespace name.
            metricName (string) -- [REQUIRED]The CloudWatch metric name.
            metricValue (string) -- [REQUIRED]The CloudWatch metric value.
            metricUnit (string) -- [REQUIRED]The metric unit supported by CloudWatch.
            metricTimestamp (string) --An optional Unix timestamp .
            cloudwatchAlarm (dict) --Change the state of a CloudWatch alarm.
            roleArn (string) -- [REQUIRED]The IAM role that allows access to the CloudWatch alarm.
            alarmName (string) -- [REQUIRED]The CloudWatch alarm name.
            stateReason (string) -- [REQUIRED]The reason for the alarm change.
            stateValue (string) -- [REQUIRED]The value of the alarm state. Acceptable values are: OK, ALARM, INSUFFICIENT_DATA.
            elasticsearch (dict) --Write data to an Amazon Elasticsearch Service domain.
            roleArn (string) -- [REQUIRED]The IAM role ARN that has access to Elasticsearch.
            endpoint (string) -- [REQUIRED]The endpoint of your Elasticsearch domain.
            index (string) -- [REQUIRED]The Elasticsearch index where you want to store your data.
            type (string) -- [REQUIRED]The type of document you are storing.
            id (string) -- [REQUIRED]The unique identifier for the document you are storing.
            
            ruleDisabled (boolean) --Specifies whether the rule is disabled.
            awsIotSqlVersion (string) --The version of the SQL rules engine to use when evaluating the rule.
            
    :type topicRulePayload: dict
    """
    pass

def set_default_policy_version(policyName=None, policyVersionId=None):
    """
    :param policyName: [REQUIRED]
            The policy name.
            
    :type policyName: string
    :param policyVersionId: [REQUIRED]
            The policy version ID.
            
    :type policyVersionId: string
    """
    pass

def set_logging_options(loggingOptionsPayload=None):
    """
    :param loggingOptionsPayload: [REQUIRED]
            The logging options payload.
            roleArn (string) -- [REQUIRED]The ARN of the IAM role that grants access.
            logLevel (string) --The logging level.
            ReturnsNone
            
    :type loggingOptionsPayload: dict
    """
    pass

def transfer_certificate(certificateId=None, targetAwsAccount=None, transferMessage=None):
    """
    :param certificateId: [REQUIRED]
            The ID of the certificate.
            
    :type certificateId: string
    :param targetAwsAccount: [REQUIRED]
            The AWS account.
            
    :type targetAwsAccount: string
    :param transferMessage: The transfer message.
    :type transferMessage: string
    """
    pass

def update_ca_certificate(certificateId=None, newStatus=None, newAutoRegistrationStatus=None):
    """
    :param certificateId: [REQUIRED]
            The CA certificate identifier.
            
    :type certificateId: string
    :param newStatus: The updated status of the CA certificate.
            Note: The status value REGISTER_INACTIVE is deprecated and should not be used.
            
    :type newStatus: string
    :param newAutoRegistrationStatus: The new value for the auto registration status. Valid values are: 'ENABLE' or 'DISABLE'.
    :type newAutoRegistrationStatus: string
    """
    pass

def update_certificate(certificateId=None, newStatus=None):
    """
    :param certificateId: [REQUIRED]
            The ID of the certificate.
            
    :type certificateId: string
    :param newStatus: [REQUIRED]
            The new status.
            Note: Setting the status to PENDING_TRANSFER will result in an exception being thrown. PENDING_TRANSFER is a status used internally by AWS IoT. It is not intended for developer use.
            Note: The status value REGISTER_INACTIVE is deprecated and should not be used.
            
    :type newStatus: string
    """
    pass

def update_thing(thingName=None, thingTypeName=None, attributePayload=None, expectedVersion=None, removeThingType=None):
    """
    :param thingName: [REQUIRED]
            The name of the thing to update.
            
    :type thingName: string
    :param thingTypeName: The name of the thing type.
    :type thingTypeName: string
    :param attributePayload: A list of thing attributes, a JSON string containing name-value pairs. For example:
            {\'attributes\':{\'name1\':\'value2\'}})
            This data is used to add new attributes or update existing attributes.
            attributes (dict) --A JSON string containing up to three key-value pair in JSON format. For example:
            {\'attributes\':{\'string1\':\'string2\'}})
            (string) --
            (string) -- An attribute value for an Thing. An empty or null value in Update means that existing value for that attribute should be deleted. Empty and null values in create are ignored.
            
            merge (boolean) --Specifies whether the list of attributes provided in the AttributePayload is merged with the attributes stored in the registry, instead of overwriting them.
            To remove an attribute, call UpdateThing with an empty attribute value.
            Note
            The merge attribute is only valid when calling UpdateThing .
            
    :type attributePayload: dict
    :param expectedVersion: The expected version of the thing record in the registry. If the version of the record in the registry does not match the expected version specified in the request, the UpdateThing request is rejected with a VersionConflictException .
    :type expectedVersion: integer
    :param removeThingType: Remove a thing type association. If true , the assocation is removed.
    :type removeThingType: boolean
    """
    pass

